==> vtk6-6.3.0-8-armv7h.pkg.tar.xz: vtk/vtkRectilinearGridPartitioner.java <==
// java wrapper for vtkRectilinearGridPartitioner object
//

package vtk;
import vtk.*;

public class vtkRectilinearGridPartitioner extends vtkMultiBlockDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfPartitions_2();
  public int GetNumberOfPartitions()
    { return GetNumberOfPartitions_2(); }

  private native void SetNumberOfPartitions_3(int id0);
  public void SetNumberOfPartitions(int id0)
    { SetNumberOfPartitions_3(id0); }

  private native int GetNumberOfGhostLayers_4();
  public int GetNumberOfGhostLayers()
    { return GetNumberOfGhostLayers_4(); }

  private native void SetNumberOfGhostLayers_5(int id0);
  public void SetNumberOfGhostLayers(int id0)
    { SetNumberOfGhostLayers_5(id0); }

  private native int GetDuplicateNodes_6();
  public int GetDuplicateNodes()
    { return GetDuplicateNodes_6(); }

  private native void SetDuplicateNodes_7(int id0);
  public void SetDuplicateNodes(int id0)
    { SetDuplicateNodes_7(id0); }

  private native void DuplicateNodesOn_8();
  public void DuplicateNodesOn()
    { DuplicateNodesOn_8(); }

  private native void DuplicateNodesOff_9();
  public void DuplicateNodesOff()
    { DuplicateNodesOff_9(); }

  public vtkRectilinearGridPartitioner() { super(); }

  public vtkRectilinearGridPartitioner(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkRectilinearGridPartitioner.java <==
// java wrapper for vtkRectilinearGridPartitioner object
//

package vtk;
import vtk.*;

public class vtkRectilinearGridPartitioner extends vtkMultiBlockDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfPartitions_2();
  public int GetNumberOfPartitions()
    { return GetNumberOfPartitions_2(); }

  private native void SetNumberOfPartitions_3(int id0);
  public void SetNumberOfPartitions(int id0)
    { SetNumberOfPartitions_3(id0); }

  private native int GetNumberOfGhostLayers_4();
  public int GetNumberOfGhostLayers()
    { return GetNumberOfGhostLayers_4(); }

  private native void SetNumberOfGhostLayers_5(int id0);
  public void SetNumberOfGhostLayers(int id0)
    { SetNumberOfGhostLayers_5(id0); }

  private native int GetDuplicateNodes_6();
  public int GetDuplicateNodes()
    { return GetDuplicateNodes_6(); }

  private native void SetDuplicateNodes_7(int id0);
  public void SetDuplicateNodes(int id0)
    { SetDuplicateNodes_7(id0); }

  private native void DuplicateNodesOn_8();
  public void DuplicateNodesOn()
    { DuplicateNodesOn_8(); }

  private native void DuplicateNodesOff_9();
  public void DuplicateNodesOff()
    { DuplicateNodesOff_9(); }

  public vtkRectilinearGridPartitioner() { super(); }

  public vtkRectilinearGridPartitioner(long id) { super(id); }
  public native long   VTKInit();

}
